@@ -23,10 +23,9 @@ function cleanup() {
 }
 trap cleanup EXIT
 
-
 python -m check_manifest --ignore ".*-requirements.txt"
 python -m sphinx.cmd.build -qnN docs docs/_build/html
-eval "$(docker-services-cli up --db ${DB:-postgresql} --search ${SEARCH:-elasticsearch} --cache ${CACHE:-redis} --env)"
+eval "$(docker-services-cli up --search ${SEARCH:-elasticsearch} --env)"
 python -m pytest
 tests_exit_code=$?
 python -m sphinx.cmd.build -qnN -b doctest docs docs/_build/doctest
